Summary:          A (transparent) caching FTP proxy
Name:             frox
Version:          0.7.18
Release:          6%{?dist}%{?pext}
License:          GPL
Group:            System Environment/Daemons
Source0:          http://%{name}.sourceforge.net/download/%{name}-%{version}.tar.bz2
Source1:          %{name}.init
Source2:          %{name}.sysconfig
Source3:          %{name}.logrotate
Patch0:           %{name}-0.7.18-config.patch
Patch1:           %{name}-0.7.18-clientdata_socket.patch
URL:              http://%{name}.sourceforge.net/
Buildroot:        %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Vendor:           James Hollingshead <frox@hollo.org>
Requires(post):   /sbin/chkconfig
Requires(preun):  /sbin/chkconfig /sbin/service
Requires(postun): /sbin/service
BuildRequires:    openssl-devel


%description
Frox is a transparent FTP proxy that runs under Linux and *BSD. It supports
caching of FTP downloads, either by redirecting through a Squid proxy, or
through its own local cache. Downloads may also be transparently scanned for
viruses (through an external scanner). Additionally there is an interface
for writing scripts to add features or modify frox's behavior. The proxy is
written with security in mind, and in the default setup runs as a non-root
user in a chroot jail.


%prep
%setup -q
%patch0 -p1
%patch1 -p1

# Prepare samples
%{__cp} -f doc/ccp-sizelimit-example.sh ccp-sizelimit-example

# Generate config
pushd src
./configen.pl configs.tpl configs.c.in configs.c
popd


%build
%configure \
	CFLAGS="${CFLAGS} -DOPENSSL_NO_KRB5 -Wno-unused" \
	--enable-ipfilter                                \
	--enable-http-cache                              \
	--enable-local-cache                             \
	--enable-virus-scan                              \
	--enable-ssl                                     \
	--enable-transparent-data                        \
	--enable-libiptc                                 \
	--enable-ccp                                     \
	--enable-procname                                \
	--enable-configfile=%{_sysconfdir}/%{name}.conf

%{__make} #%{?_smp_mflags}

# Build samples
%{__cc} ${CFLAGS} -o ccp-mirrors-example doc/ccp-mirrors-example.c


%install
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_initrddir}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_sysconfdir}/{logrotate.d,sysconfig}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_libexecdir}/%{name}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_mandir}/{man5,man8}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_localstatedir}/cache/%{name}

%{__make} \
	DESTDIR=${RPM_BUILD_ROOT} \
	install

%{__install} -m 0755 %{SOURCE1}       ${RPM_BUILD_ROOT}%{_initrddir}/%{name}
%{__install} -m 0644 %{SOURCE2}       ${RPM_BUILD_ROOT}%{_sysconfdir}/sysconfig/%{name}
%{__install} -m 0644 %{SOURCE3}       ${RPM_BUILD_ROOT}%{_sysconfdir}/logrotate.d/%{name}

%{__install} -m 0640 src/%{name}.conf ${RPM_BUILD_ROOT}%{_sysconfdir}

pushd doc
%{__install} -m 0644 %{name}.conf.man ${RPM_BUILD_ROOT}%{_mandir}/man5/%{name}.conf.5
%{__install} -m 0644 %{name}.man      ${RPM_BUILD_ROOT}%{_mandir}/man8/%{name}.8
popd

%{__install} -m 0700 ccp-*-example    ${RPM_BUILD_ROOT}%{_libexecdir}/%{name}


%pre
if ! getent group  %{name} >/dev/null 2>&1; then
  /usr/sbin/groupadd -r %{name}
fi
if ! getent passwd %{name} >/dev/null 2>&1; then
  /usr/sbin/useradd  -r -g %{name}       \
	-d %{_localstatedir}/lib/%{name} \
	-c "Frox Service user"           \
	-s /sbin/nologin %{name}
fi
exit 0			# Always pass


%post
/sbin/chkconfig --add %{name}


%preun
if [ $1 -eq 0 ]; then	# Remove
  /sbin/service %{name} stop >/dev/null 2>&1
  /sbin/chkconfig --del %{name}
fi


%postun
if [ $1 -ge 1 ]; then	# Upgrade
  /sbin/service %{name} condrestart >/dev/null 2>&1 || :
fi


%clean
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,root)
%doc BUGS COPYING README
%doc doc/{CREDITS,ChangeLog,FAQ,FAQ*.html,INSTALL}
%doc doc/{INTERNALS,README*,RELEASE,SECURITY,TODO}
%{_initrddir}/%{name}
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%attr(640,root,%{name}) %config(noreplace) %{_sysconfdir}/%{name}.conf
%{_libexecdir}/%{name}
%{_sbindir}/%{name}
%{_mandir}/man5/%{name}.conf.5*
%{_mandir}/man8/%{name}.8*
%attr(750,%{name},%{name}) %dir %{_localstatedir}/cache/%{name}


%changelog
* Mon Dec 01 2008 Peter Pramberger <peterpramb@member.fsf.org> - 0.7.18-6
- Rewritten for buildsystem

* Fri Jan 19 2007 peter.pramberger@member.fsf.org 0.7.18-5
- some spec file cleanups (x86_64 support)

* Mon Nov 27 2006 peter.pramberger@member.fsf.org 0.7.18-4
- added client active mode source address fix

* Mon Dec 12 2005 peter.pramberger@member.fsf.org
- some spec file cleanups

* Fri Aug 26 2005 peter.pramberger@member.fsf.org
- created
